# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MultipathDevice(object):
    """
    Secondary multipath device, it uses the charUsername and chapSecret from primary volume attachment
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MultipathDevice object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ipv4:
            The value to assign to the ipv4 property of this MultipathDevice.
        :type ipv4: str

        :param iqn:
            The value to assign to the iqn property of this MultipathDevice.
        :type iqn: str

        :param port:
            The value to assign to the port property of this MultipathDevice.
        :type port: int

        """
        self.swagger_types = {
            'ipv4': 'str',
            'iqn': 'str',
            'port': 'int'
        }

        self.attribute_map = {
            'ipv4': 'ipv4',
            'iqn': 'iqn',
            'port': 'port'
        }

        self._ipv4 = None
        self._iqn = None
        self._port = None

    @property
    def ipv4(self):
        """
        **[Required]** Gets the ipv4 of this MultipathDevice.
        The volume's iSCSI IP address.

        Example: `169.254.2.2`


        :return: The ipv4 of this MultipathDevice.
        :rtype: str
        """
        return self._ipv4

    @ipv4.setter
    def ipv4(self, ipv4):
        """
        Sets the ipv4 of this MultipathDevice.
        The volume's iSCSI IP address.

        Example: `169.254.2.2`


        :param ipv4: The ipv4 of this MultipathDevice.
        :type: str
        """
        self._ipv4 = ipv4

    @property
    def iqn(self):
        """
        **[Required]** Gets the iqn of this MultipathDevice.
        The target volume's iSCSI Qualified Name in the format defined
        by `RFC 3720`__.

        Example: `iqn.2015-12.com.oracleiaas:40b7ee03-883f-46c6-a951-63d2841d2195`

        __ https://tools.ietf.org/html/rfc3720#page-32


        :return: The iqn of this MultipathDevice.
        :rtype: str
        """
        return self._iqn

    @iqn.setter
    def iqn(self, iqn):
        """
        Sets the iqn of this MultipathDevice.
        The target volume's iSCSI Qualified Name in the format defined
        by `RFC 3720`__.

        Example: `iqn.2015-12.com.oracleiaas:40b7ee03-883f-46c6-a951-63d2841d2195`

        __ https://tools.ietf.org/html/rfc3720#page-32


        :param iqn: The iqn of this MultipathDevice.
        :type: str
        """
        self._iqn = iqn

    @property
    def port(self):
        """
        Gets the port of this MultipathDevice.
        The volume's iSCSI port, usually port 860 or 3260.

        Example: `3260`


        :return: The port of this MultipathDevice.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this MultipathDevice.
        The volume's iSCSI port, usually port 860 or 3260.

        Example: `3260`


        :param port: The port of this MultipathDevice.
        :type: int
        """
        self._port = port

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RuleSummary(object):
    """
    A list of rule resources. One or more rules can be defined for a data entity.
    Each rule can be defined on one or more attributes of the data entity.
    """

    #: A constant which can be used with the rule_type property of a RuleSummary.
    #: This constant has a value of "PRIMARYKEY"
    RULE_TYPE_PRIMARYKEY = "PRIMARYKEY"

    #: A constant which can be used with the rule_type property of a RuleSummary.
    #: This constant has a value of "FOREIGNKEY"
    RULE_TYPE_FOREIGNKEY = "FOREIGNKEY"

    #: A constant which can be used with the rule_type property of a RuleSummary.
    #: This constant has a value of "UNIQUEKEY"
    RULE_TYPE_UNIQUEKEY = "UNIQUEKEY"

    #: A constant which can be used with the origin_type property of a RuleSummary.
    #: This constant has a value of "SOURCE"
    ORIGIN_TYPE_SOURCE = "SOURCE"

    #: A constant which can be used with the origin_type property of a RuleSummary.
    #: This constant has a value of "USER"
    ORIGIN_TYPE_USER = "USER"

    #: A constant which can be used with the origin_type property of a RuleSummary.
    #: This constant has a value of "PROFILING"
    ORIGIN_TYPE_PROFILING = "PROFILING"

    #: A constant which can be used with the lifecycle_state property of a RuleSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a RuleSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a RuleSummary.
    #: This constant has a value of "INACTIVE"
    LIFECYCLE_STATE_INACTIVE = "INACTIVE"

    #: A constant which can be used with the lifecycle_state property of a RuleSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a RuleSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a RuleSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a RuleSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a RuleSummary.
    #: This constant has a value of "MOVING"
    LIFECYCLE_STATE_MOVING = "MOVING"

    def __init__(self, **kwargs):
        """
        Initializes a new RuleSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this RuleSummary.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this RuleSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this RuleSummary.
        :type description: str

        :param rule_type:
            The value to assign to the rule_type property of this RuleSummary.
            Allowed values for this property are: "PRIMARYKEY", "FOREIGNKEY", "UNIQUEKEY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type rule_type: str

        :param external_key:
            The value to assign to the external_key property of this RuleSummary.
        :type external_key: str

        :param attributes:
            The value to assign to the attributes property of this RuleSummary.
        :type attributes: list[oci.data_catalog.models.RuleAttribute]

        :param referenced_folder_key:
            The value to assign to the referenced_folder_key property of this RuleSummary.
        :type referenced_folder_key: str

        :param referenced_folder_name:
            The value to assign to the referenced_folder_name property of this RuleSummary.
        :type referenced_folder_name: str

        :param referenced_entity_key:
            The value to assign to the referenced_entity_key property of this RuleSummary.
        :type referenced_entity_key: str

        :param referenced_entity_name:
            The value to assign to the referenced_entity_name property of this RuleSummary.
        :type referenced_entity_name: str

        :param referenced_rule_key:
            The value to assign to the referenced_rule_key property of this RuleSummary.
        :type referenced_rule_key: str

        :param referenced_rule_name:
            The value to assign to the referenced_rule_name property of this RuleSummary.
        :type referenced_rule_name: str

        :param referenced_attributes:
            The value to assign to the referenced_attributes property of this RuleSummary.
        :type referenced_attributes: list[oci.data_catalog.models.RuleAttribute]

        :param origin_type:
            The value to assign to the origin_type property of this RuleSummary.
            Allowed values for this property are: "SOURCE", "USER", "PROFILING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type origin_type: str

        :param uri:
            The value to assign to the uri property of this RuleSummary.
        :type uri: str

        :param time_created:
            The value to assign to the time_created property of this RuleSummary.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this RuleSummary.
            Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'description': 'str',
            'rule_type': 'str',
            'external_key': 'str',
            'attributes': 'list[RuleAttribute]',
            'referenced_folder_key': 'str',
            'referenced_folder_name': 'str',
            'referenced_entity_key': 'str',
            'referenced_entity_name': 'str',
            'referenced_rule_key': 'str',
            'referenced_rule_name': 'str',
            'referenced_attributes': 'list[RuleAttribute]',
            'origin_type': 'str',
            'uri': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'description': 'description',
            'rule_type': 'ruleType',
            'external_key': 'externalKey',
            'attributes': 'attributes',
            'referenced_folder_key': 'referencedFolderKey',
            'referenced_folder_name': 'referencedFolderName',
            'referenced_entity_key': 'referencedEntityKey',
            'referenced_entity_name': 'referencedEntityName',
            'referenced_rule_key': 'referencedRuleKey',
            'referenced_rule_name': 'referencedRuleName',
            'referenced_attributes': 'referencedAttributes',
            'origin_type': 'originType',
            'uri': 'uri',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState'
        }

        self._key = None
        self._display_name = None
        self._description = None
        self._rule_type = None
        self._external_key = None
        self._attributes = None
        self._referenced_folder_key = None
        self._referenced_folder_name = None
        self._referenced_entity_key = None
        self._referenced_entity_name = None
        self._referenced_rule_key = None
        self._referenced_rule_name = None
        self._referenced_attributes = None
        self._origin_type = None
        self._uri = None
        self._time_created = None
        self._lifecycle_state = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this RuleSummary.
        Immutable unique key of a rule.


        :return: The key of this RuleSummary.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this RuleSummary.
        Immutable unique key of a rule.


        :param key: The key of this RuleSummary.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this RuleSummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this RuleSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this RuleSummary.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this RuleSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def description(self):
        """
        Gets the description of this RuleSummary.
        Detailed description of a rule.


        :return: The description of this RuleSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this RuleSummary.
        Detailed description of a rule.


        :param description: The description of this RuleSummary.
        :type: str
        """
        self._description = description

    @property
    def rule_type(self):
        """
        Gets the rule_type of this RuleSummary.
        Type of a rule.

        Allowed values for this property are: "PRIMARYKEY", "FOREIGNKEY", "UNIQUEKEY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The rule_type of this RuleSummary.
        :rtype: str
        """
        return self._rule_type

    @rule_type.setter
    def rule_type(self, rule_type):
        """
        Sets the rule_type of this RuleSummary.
        Type of a rule.


        :param rule_type: The rule_type of this RuleSummary.
        :type: str
        """
        allowed_values = ["PRIMARYKEY", "FOREIGNKEY", "UNIQUEKEY"]
        if not value_allowed_none_or_none_sentinel(rule_type, allowed_values):
            rule_type = 'UNKNOWN_ENUM_VALUE'
        self._rule_type = rule_type

    @property
    def external_key(self):
        """
        Gets the external_key of this RuleSummary.
        External URI that can be used to reference the object. Format will differ based on the type of object.


        :return: The external_key of this RuleSummary.
        :rtype: str
        """
        return self._external_key

    @external_key.setter
    def external_key(self, external_key):
        """
        Sets the external_key of this RuleSummary.
        External URI that can be used to reference the object. Format will differ based on the type of object.


        :param external_key: The external_key of this RuleSummary.
        :type: str
        """
        self._external_key = external_key

    @property
    def attributes(self):
        """
        Gets the attributes of this RuleSummary.
        Attributes associated with a rule.
        A UNIQUEKEY rule would contain (at least) one attribute, for the local table column(s) on which uniqueness is defined.


        :return: The attributes of this RuleSummary.
        :rtype: list[oci.data_catalog.models.RuleAttribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this RuleSummary.
        Attributes associated with a rule.
        A UNIQUEKEY rule would contain (at least) one attribute, for the local table column(s) on which uniqueness is defined.


        :param attributes: The attributes of this RuleSummary.
        :type: list[oci.data_catalog.models.RuleAttribute]
        """
        self._attributes = attributes

    @property
    def referenced_folder_key(self):
        """
        Gets the referenced_folder_key of this RuleSummary.
        Folder key that represents the referenced folder, applicable only when rule type FOREIGNKEY.


        :return: The referenced_folder_key of this RuleSummary.
        :rtype: str
        """
        return self._referenced_folder_key

    @referenced_folder_key.setter
    def referenced_folder_key(self, referenced_folder_key):
        """
        Sets the referenced_folder_key of this RuleSummary.
        Folder key that represents the referenced folder, applicable only when rule type FOREIGNKEY.


        :param referenced_folder_key: The referenced_folder_key of this RuleSummary.
        :type: str
        """
        self._referenced_folder_key = referenced_folder_key

    @property
    def referenced_folder_name(self):
        """
        Gets the referenced_folder_name of this RuleSummary.
        Folder name that represents the referenced folder, applicable only when rule type FOREIGNKEY.


        :return: The referenced_folder_name of this RuleSummary.
        :rtype: str
        """
        return self._referenced_folder_name

    @referenced_folder_name.setter
    def referenced_folder_name(self, referenced_folder_name):
        """
        Sets the referenced_folder_name of this RuleSummary.
        Folder name that represents the referenced folder, applicable only when rule type FOREIGNKEY.


        :param referenced_folder_name: The referenced_folder_name of this RuleSummary.
        :type: str
        """
        self._referenced_folder_name = referenced_folder_name

    @property
    def referenced_entity_key(self):
        """
        Gets the referenced_entity_key of this RuleSummary.
        Entity key that represents the referenced entity, applicable only when rule type is FOREIGNKEY.


        :return: The referenced_entity_key of this RuleSummary.
        :rtype: str
        """
        return self._referenced_entity_key

    @referenced_entity_key.setter
    def referenced_entity_key(self, referenced_entity_key):
        """
        Sets the referenced_entity_key of this RuleSummary.
        Entity key that represents the referenced entity, applicable only when rule type is FOREIGNKEY.


        :param referenced_entity_key: The referenced_entity_key of this RuleSummary.
        :type: str
        """
        self._referenced_entity_key = referenced_entity_key

    @property
    def referenced_entity_name(self):
        """
        Gets the referenced_entity_name of this RuleSummary.
        Entity name that represents the referenced entity, applicable only when rule type is FOREIGNKEY.


        :return: The referenced_entity_name of this RuleSummary.
        :rtype: str
        """
        return self._referenced_entity_name

    @referenced_entity_name.setter
    def referenced_entity_name(self, referenced_entity_name):
        """
        Sets the referenced_entity_name of this RuleSummary.
        Entity name that represents the referenced entity, applicable only when rule type is FOREIGNKEY.


        :param referenced_entity_name: The referenced_entity_name of this RuleSummary.
        :type: str
        """
        self._referenced_entity_name = referenced_entity_name

    @property
    def referenced_rule_key(self):
        """
        Gets the referenced_rule_key of this RuleSummary.
        Rule key that represents the referenced rule, applicable only when rule type is FOREIGNKEY.


        :return: The referenced_rule_key of this RuleSummary.
        :rtype: str
        """
        return self._referenced_rule_key

    @referenced_rule_key.setter
    def referenced_rule_key(self, referenced_rule_key):
        """
        Sets the referenced_rule_key of this RuleSummary.
        Rule key that represents the referenced rule, applicable only when rule type is FOREIGNKEY.


        :param referenced_rule_key: The referenced_rule_key of this RuleSummary.
        :type: str
        """
        self._referenced_rule_key = referenced_rule_key

    @property
    def referenced_rule_name(self):
        """
        Gets the referenced_rule_name of this RuleSummary.
        Rule name that represents the referenced rule, applicable only when rule type is FOREIGNKEY.


        :return: The referenced_rule_name of this RuleSummary.
        :rtype: str
        """
        return self._referenced_rule_name

    @referenced_rule_name.setter
    def referenced_rule_name(self, referenced_rule_name):
        """
        Sets the referenced_rule_name of this RuleSummary.
        Rule name that represents the referenced rule, applicable only when rule type is FOREIGNKEY.


        :param referenced_rule_name: The referenced_rule_name of this RuleSummary.
        :type: str
        """
        self._referenced_rule_name = referenced_rule_name

    @property
    def referenced_attributes(self):
        """
        Gets the referenced_attributes of this RuleSummary.
        Attributes associated with referenced rule, applicable only when rule type is FOREIGNKEY.
        A FOREIGNKEY rule would contain (at least) one attribute, for the local table column(s), and (at least) one referencedAttribute for referenced table column(s).


        :return: The referenced_attributes of this RuleSummary.
        :rtype: list[oci.data_catalog.models.RuleAttribute]
        """
        return self._referenced_attributes

    @referenced_attributes.setter
    def referenced_attributes(self, referenced_attributes):
        """
        Sets the referenced_attributes of this RuleSummary.
        Attributes associated with referenced rule, applicable only when rule type is FOREIGNKEY.
        A FOREIGNKEY rule would contain (at least) one attribute, for the local table column(s), and (at least) one referencedAttribute for referenced table column(s).


        :param referenced_attributes: The referenced_attributes of this RuleSummary.
        :type: list[oci.data_catalog.models.RuleAttribute]
        """
        self._referenced_attributes = referenced_attributes

    @property
    def origin_type(self):
        """
        Gets the origin_type of this RuleSummary.
        Origin type of the rule.

        Allowed values for this property are: "SOURCE", "USER", "PROFILING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The origin_type of this RuleSummary.
        :rtype: str
        """
        return self._origin_type

    @origin_type.setter
    def origin_type(self, origin_type):
        """
        Sets the origin_type of this RuleSummary.
        Origin type of the rule.


        :param origin_type: The origin_type of this RuleSummary.
        :type: str
        """
        allowed_values = ["SOURCE", "USER", "PROFILING"]
        if not value_allowed_none_or_none_sentinel(origin_type, allowed_values):
            origin_type = 'UNKNOWN_ENUM_VALUE'
        self._origin_type = origin_type

    @property
    def uri(self):
        """
        Gets the uri of this RuleSummary.
        URI to the rule instance in the API.


        :return: The uri of this RuleSummary.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this RuleSummary.
        URI to the rule instance in the API.


        :param uri: The uri of this RuleSummary.
        :type: str
        """
        self._uri = uri

    @property
    def time_created(self):
        """
        Gets the time_created of this RuleSummary.
        The date and time the rule was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this RuleSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this RuleSummary.
        The date and time the rule was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this RuleSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this RuleSummary.
        State of the rule.

        Allowed values for this property are: "CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this RuleSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this RuleSummary.
        State of the rule.


        :param lifecycle_state: The lifecycle_state of this RuleSummary.
        :type: str
        """
        allowed_values = ["CREATING", "ACTIVE", "INACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", "MOVING"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ConfirmationResult(object):
    """
    The confirmation details for the specified subscription.
    For information about confirming subscriptions, see
    `To confirm a subscription`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Notification/Tasks/managingtopicsandsubscriptions.htm#confirmSub
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ConfirmationResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param topic_name:
            The value to assign to the topic_name property of this ConfirmationResult.
        :type topic_name: str

        :param topic_id:
            The value to assign to the topic_id property of this ConfirmationResult.
        :type topic_id: str

        :param endpoint:
            The value to assign to the endpoint property of this ConfirmationResult.
        :type endpoint: str

        :param unsubscribe_url:
            The value to assign to the unsubscribe_url property of this ConfirmationResult.
        :type unsubscribe_url: str

        :param message:
            The value to assign to the message property of this ConfirmationResult.
        :type message: str

        :param subscription_id:
            The value to assign to the subscription_id property of this ConfirmationResult.
        :type subscription_id: str

        """
        self.swagger_types = {
            'topic_name': 'str',
            'topic_id': 'str',
            'endpoint': 'str',
            'unsubscribe_url': 'str',
            'message': 'str',
            'subscription_id': 'str'
        }

        self.attribute_map = {
            'topic_name': 'topicName',
            'topic_id': 'topicId',
            'endpoint': 'endpoint',
            'unsubscribe_url': 'unsubscribeUrl',
            'message': 'message',
            'subscription_id': 'subscriptionId'
        }

        self._topic_name = None
        self._topic_id = None
        self._endpoint = None
        self._unsubscribe_url = None
        self._message = None
        self._subscription_id = None

    @property
    def topic_name(self):
        """
        **[Required]** Gets the topic_name of this ConfirmationResult.
        The name of the subscribed topic.


        :return: The topic_name of this ConfirmationResult.
        :rtype: str
        """
        return self._topic_name

    @topic_name.setter
    def topic_name(self, topic_name):
        """
        Sets the topic_name of this ConfirmationResult.
        The name of the subscribed topic.


        :param topic_name: The topic_name of this ConfirmationResult.
        :type: str
        """
        self._topic_name = topic_name

    @property
    def topic_id(self):
        """
        **[Required]** Gets the topic_id of this ConfirmationResult.
        The `OCID`__ of the topic associated with the specified subscription.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The topic_id of this ConfirmationResult.
        :rtype: str
        """
        return self._topic_id

    @topic_id.setter
    def topic_id(self, topic_id):
        """
        Sets the topic_id of this ConfirmationResult.
        The `OCID`__ of the topic associated with the specified subscription.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param topic_id: The topic_id of this ConfirmationResult.
        :type: str
        """
        self._topic_id = topic_id

    @property
    def endpoint(self):
        """
        **[Required]** Gets the endpoint of this ConfirmationResult.
        A locator that corresponds to the subscription protocol.
        For example, an email address for a subscription that uses the `EMAIL` protocol, or a URL for a subscription that uses an HTTP-based protocol.


        :return: The endpoint of this ConfirmationResult.
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """
        Sets the endpoint of this ConfirmationResult.
        A locator that corresponds to the subscription protocol.
        For example, an email address for a subscription that uses the `EMAIL` protocol, or a URL for a subscription that uses an HTTP-based protocol.


        :param endpoint: The endpoint of this ConfirmationResult.
        :type: str
        """
        self._endpoint = endpoint

    @property
    def unsubscribe_url(self):
        """
        **[Required]** Gets the unsubscribe_url of this ConfirmationResult.
        The URL for unsubscribing from the topic.


        :return: The unsubscribe_url of this ConfirmationResult.
        :rtype: str
        """
        return self._unsubscribe_url

    @unsubscribe_url.setter
    def unsubscribe_url(self, unsubscribe_url):
        """
        Sets the unsubscribe_url of this ConfirmationResult.
        The URL for unsubscribing from the topic.


        :param unsubscribe_url: The unsubscribe_url of this ConfirmationResult.
        :type: str
        """
        self._unsubscribe_url = unsubscribe_url

    @property
    def message(self):
        """
        **[Required]** Gets the message of this ConfirmationResult.
        A human-readable string indicating the status of the subscription confirmation.


        :return: The message of this ConfirmationResult.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this ConfirmationResult.
        A human-readable string indicating the status of the subscription confirmation.


        :param message: The message of this ConfirmationResult.
        :type: str
        """
        self._message = message

    @property
    def subscription_id(self):
        """
        **[Required]** Gets the subscription_id of this ConfirmationResult.
        The `OCID`__ of the subscription specified in the request.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The subscription_id of this ConfirmationResult.
        :rtype: str
        """
        return self._subscription_id

    @subscription_id.setter
    def subscription_id(self, subscription_id):
        """
        Sets the subscription_id of this ConfirmationResult.
        The `OCID`__ of the subscription specified in the request.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param subscription_id: The subscription_id of this ConfirmationResult.
        :type: str
        """
        self._subscription_id = subscription_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JobSummary(object):
    """
    A summary of the job.
    """

    #: A constant which can be used with the database_sub_type property of a JobSummary.
    #: This constant has a value of "CDB"
    DATABASE_SUB_TYPE_CDB = "CDB"

    #: A constant which can be used with the database_sub_type property of a JobSummary.
    #: This constant has a value of "PDB"
    DATABASE_SUB_TYPE_PDB = "PDB"

    #: A constant which can be used with the database_sub_type property of a JobSummary.
    #: This constant has a value of "NON_CDB"
    DATABASE_SUB_TYPE_NON_CDB = "NON_CDB"

    #: A constant which can be used with the job_type property of a JobSummary.
    #: This constant has a value of "SQL"
    JOB_TYPE_SQL = "SQL"

    def __init__(self, **kwargs):
        """
        Initializes a new JobSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this JobSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this JobSummary.
        :type compartment_id: str

        :param name:
            The value to assign to the name property of this JobSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this JobSummary.
        :type description: str

        :param managed_database_group_id:
            The value to assign to the managed_database_group_id property of this JobSummary.
        :type managed_database_group_id: str

        :param managed_database_id:
            The value to assign to the managed_database_id property of this JobSummary.
        :type managed_database_id: str

        :param database_sub_type:
            The value to assign to the database_sub_type property of this JobSummary.
            Allowed values for this property are: "CDB", "PDB", "NON_CDB", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type database_sub_type: str

        :param schedule_type:
            The value to assign to the schedule_type property of this JobSummary.
        :type schedule_type: str

        :param schedule_details:
            The value to assign to the schedule_details property of this JobSummary.
        :type schedule_details: oci.database_management.models.JobScheduleDetails

        :param job_type:
            The value to assign to the job_type property of this JobSummary.
            Allowed values for this property are: "SQL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type job_type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this JobSummary.
        :type lifecycle_state: str

        :param timeout:
            The value to assign to the timeout property of this JobSummary.
        :type timeout: str

        :param submission_error_message:
            The value to assign to the submission_error_message property of this JobSummary.
        :type submission_error_message: str

        :param time_created:
            The value to assign to the time_created property of this JobSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this JobSummary.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'name': 'str',
            'description': 'str',
            'managed_database_group_id': 'str',
            'managed_database_id': 'str',
            'database_sub_type': 'str',
            'schedule_type': 'str',
            'schedule_details': 'JobScheduleDetails',
            'job_type': 'str',
            'lifecycle_state': 'str',
            'timeout': 'str',
            'submission_error_message': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'name': 'name',
            'description': 'description',
            'managed_database_group_id': 'managedDatabaseGroupId',
            'managed_database_id': 'managedDatabaseId',
            'database_sub_type': 'databaseSubType',
            'schedule_type': 'scheduleType',
            'schedule_details': 'scheduleDetails',
            'job_type': 'jobType',
            'lifecycle_state': 'lifecycleState',
            'timeout': 'timeout',
            'submission_error_message': 'submissionErrorMessage',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated'
        }

        self._id = None
        self._compartment_id = None
        self._name = None
        self._description = None
        self._managed_database_group_id = None
        self._managed_database_id = None
        self._database_sub_type = None
        self._schedule_type = None
        self._schedule_details = None
        self._job_type = None
        self._lifecycle_state = None
        self._timeout = None
        self._submission_error_message = None
        self._time_created = None
        self._time_updated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this JobSummary.
        The `OCID`__ of the job.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this JobSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this JobSummary.
        The `OCID`__ of the job.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this JobSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this JobSummary.
        The `OCID`__ of the compartment in which the job resides.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this JobSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this JobSummary.
        The `OCID`__ of the compartment in which the job resides.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this JobSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this JobSummary.
        The display name of the job.


        :return: The name of this JobSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this JobSummary.
        The display name of the job.


        :param name: The name of this JobSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this JobSummary.
        The description of the job.


        :return: The description of this JobSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this JobSummary.
        The description of the job.


        :param description: The description of this JobSummary.
        :type: str
        """
        self._description = description

    @property
    def managed_database_group_id(self):
        """
        Gets the managed_database_group_id of this JobSummary.
        The `OCID`__ of the Managed Database Group where the job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The managed_database_group_id of this JobSummary.
        :rtype: str
        """
        return self._managed_database_group_id

    @managed_database_group_id.setter
    def managed_database_group_id(self, managed_database_group_id):
        """
        Sets the managed_database_group_id of this JobSummary.
        The `OCID`__ of the Managed Database Group where the job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param managed_database_group_id: The managed_database_group_id of this JobSummary.
        :type: str
        """
        self._managed_database_group_id = managed_database_group_id

    @property
    def managed_database_id(self):
        """
        Gets the managed_database_id of this JobSummary.
        The `OCID`__ of the Managed Database where the job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The managed_database_id of this JobSummary.
        :rtype: str
        """
        return self._managed_database_id

    @managed_database_id.setter
    def managed_database_id(self, managed_database_id):
        """
        Sets the managed_database_id of this JobSummary.
        The `OCID`__ of the Managed Database where the job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param managed_database_id: The managed_database_id of this JobSummary.
        :type: str
        """
        self._managed_database_id = managed_database_id

    @property
    def database_sub_type(self):
        """
        Gets the database_sub_type of this JobSummary.
        The subtype of the Oracle Database where the job has to be executed. Only applicable when managedDatabaseGroupId is provided.

        Allowed values for this property are: "CDB", "PDB", "NON_CDB", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The database_sub_type of this JobSummary.
        :rtype: str
        """
        return self._database_sub_type

    @database_sub_type.setter
    def database_sub_type(self, database_sub_type):
        """
        Sets the database_sub_type of this JobSummary.
        The subtype of the Oracle Database where the job has to be executed. Only applicable when managedDatabaseGroupId is provided.


        :param database_sub_type: The database_sub_type of this JobSummary.
        :type: str
        """
        allowed_values = ["CDB", "PDB", "NON_CDB"]
        if not value_allowed_none_or_none_sentinel(database_sub_type, allowed_values):
            database_sub_type = 'UNKNOWN_ENUM_VALUE'
        self._database_sub_type = database_sub_type

    @property
    def schedule_type(self):
        """
        **[Required]** Gets the schedule_type of this JobSummary.
        The schedule type of the job.


        :return: The schedule_type of this JobSummary.
        :rtype: str
        """
        return self._schedule_type

    @schedule_type.setter
    def schedule_type(self, schedule_type):
        """
        Sets the schedule_type of this JobSummary.
        The schedule type of the job.


        :param schedule_type: The schedule_type of this JobSummary.
        :type: str
        """
        self._schedule_type = schedule_type

    @property
    def schedule_details(self):
        """
        Gets the schedule_details of this JobSummary.

        :return: The schedule_details of this JobSummary.
        :rtype: oci.database_management.models.JobScheduleDetails
        """
        return self._schedule_details

    @schedule_details.setter
    def schedule_details(self, schedule_details):
        """
        Sets the schedule_details of this JobSummary.

        :param schedule_details: The schedule_details of this JobSummary.
        :type: oci.database_management.models.JobScheduleDetails
        """
        self._schedule_details = schedule_details

    @property
    def job_type(self):
        """
        **[Required]** Gets the job_type of this JobSummary.
        The type of job.

        Allowed values for this property are: "SQL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The job_type of this JobSummary.
        :rtype: str
        """
        return self._job_type

    @job_type.setter
    def job_type(self, job_type):
        """
        Sets the job_type of this JobSummary.
        The type of job.


        :param job_type: The job_type of this JobSummary.
        :type: str
        """
        allowed_values = ["SQL"]
        if not value_allowed_none_or_none_sentinel(job_type, allowed_values):
            job_type = 'UNKNOWN_ENUM_VALUE'
        self._job_type = job_type

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this JobSummary.
        The lifecycle state of the job.


        :return: The lifecycle_state of this JobSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this JobSummary.
        The lifecycle state of the job.


        :param lifecycle_state: The lifecycle_state of this JobSummary.
        :type: str
        """
        self._lifecycle_state = lifecycle_state

    @property
    def timeout(self):
        """
        Gets the timeout of this JobSummary.
        The job timeout duration, which is expressed like \"1h 10m 15s\".


        :return: The timeout of this JobSummary.
        :rtype: str
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """
        Sets the timeout of this JobSummary.
        The job timeout duration, which is expressed like \"1h 10m 15s\".


        :param timeout: The timeout of this JobSummary.
        :type: str
        """
        self._timeout = timeout

    @property
    def submission_error_message(self):
        """
        Gets the submission_error_message of this JobSummary.
        The error message that is returned if the job submission fails. Null is returned in all other scenarios.


        :return: The submission_error_message of this JobSummary.
        :rtype: str
        """
        return self._submission_error_message

    @submission_error_message.setter
    def submission_error_message(self, submission_error_message):
        """
        Sets the submission_error_message of this JobSummary.
        The error message that is returned if the job submission fails. Null is returned in all other scenarios.


        :param submission_error_message: The submission_error_message of this JobSummary.
        :type: str
        """
        self._submission_error_message = submission_error_message

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this JobSummary.
        The date and time when the job was created.


        :return: The time_created of this JobSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this JobSummary.
        The date and time when the job was created.


        :param time_created: The time_created of this JobSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this JobSummary.
        The date and time when the job was last updated.


        :return: The time_updated of this JobSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this JobSummary.
        The date and time when the job was last updated.


        :param time_updated: The time_updated of this JobSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .application import Application
from .application_parameter import ApplicationParameter
from .application_summary import ApplicationSummary
from .change_application_compartment_details import ChangeApplicationCompartmentDetails
from .change_private_endpoint_compartment_details import ChangePrivateEndpointCompartmentDetails
from .change_run_compartment_details import ChangeRunCompartmentDetails
from .create_application_details import CreateApplicationDetails
from .create_private_endpoint_details import CreatePrivateEndpointDetails
from .create_run_details import CreateRunDetails
from .private_endpoint import PrivateEndpoint
from .private_endpoint_collection import PrivateEndpointCollection
from .private_endpoint_summary import PrivateEndpointSummary
from .run import Run
from .run_log_summary import RunLogSummary
from .run_summary import RunSummary
from .update_application_details import UpdateApplicationDetails
from .update_private_endpoint_details import UpdatePrivateEndpointDetails
from .update_run_details import UpdateRunDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log import WorkRequestLog
from .work_request_log_collection import WorkRequestLogCollection
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for data_flow services.
data_flow_type_mapping = {
    "Application": Application,
    "ApplicationParameter": ApplicationParameter,
    "ApplicationSummary": ApplicationSummary,
    "ChangeApplicationCompartmentDetails": ChangeApplicationCompartmentDetails,
    "ChangePrivateEndpointCompartmentDetails": ChangePrivateEndpointCompartmentDetails,
    "ChangeRunCompartmentDetails": ChangeRunCompartmentDetails,
    "CreateApplicationDetails": CreateApplicationDetails,
    "CreatePrivateEndpointDetails": CreatePrivateEndpointDetails,
    "CreateRunDetails": CreateRunDetails,
    "PrivateEndpoint": PrivateEndpoint,
    "PrivateEndpointCollection": PrivateEndpointCollection,
    "PrivateEndpointSummary": PrivateEndpointSummary,
    "Run": Run,
    "RunLogSummary": RunLogSummary,
    "RunSummary": RunSummary,
    "UpdateApplicationDetails": UpdateApplicationDetails,
    "UpdatePrivateEndpointDetails": UpdatePrivateEndpointDetails,
    "UpdateRunDetails": UpdateRunDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLog": WorkRequestLog,
    "WorkRequestLogCollection": WorkRequestLogCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RoutingRule(object):
    """
    A routing rule examines an incoming request, routing matching requests to the specified backend set.
    Routing rules apply only to HTTP and HTTPS requests. They have no effect on TCP requests.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RoutingRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this RoutingRule.
        :type name: str

        :param condition:
            The value to assign to the condition property of this RoutingRule.
        :type condition: str

        :param actions:
            The value to assign to the actions property of this RoutingRule.
        :type actions: list[oci.load_balancer.models.Action]

        """
        self.swagger_types = {
            'name': 'str',
            'condition': 'str',
            'actions': 'list[Action]'
        }

        self.attribute_map = {
            'name': 'name',
            'condition': 'condition',
            'actions': 'actions'
        }

        self._name = None
        self._condition = None
        self._actions = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this RoutingRule.
        A unique name for the routing policy rule. Avoid entering confidential information.


        :return: The name of this RoutingRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this RoutingRule.
        A unique name for the routing policy rule. Avoid entering confidential information.


        :param name: The name of this RoutingRule.
        :type: str
        """
        self._name = name

    @property
    def condition(self):
        """
        **[Required]** Gets the condition of this RoutingRule.
        A routing rule to evaluate defined conditions against the incoming HTTP request and perform an action.


        :return: The condition of this RoutingRule.
        :rtype: str
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this RoutingRule.
        A routing rule to evaluate defined conditions against the incoming HTTP request and perform an action.


        :param condition: The condition of this RoutingRule.
        :type: str
        """
        self._condition = condition

    @property
    def actions(self):
        """
        **[Required]** Gets the actions of this RoutingRule.
        A list of actions to be applied when conditions of the routing rule are met.


        :return: The actions of this RoutingRule.
        :rtype: list[oci.load_balancer.models.Action]
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """
        Sets the actions of this RoutingRule.
        A list of actions to be applied when conditions of the routing rule are met.


        :param actions: The actions of this RoutingRule.
        :type: list[oci.load_balancer.models.Action]
        """
        self._actions = actions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NetworkSecurityGroupVnic(object):
    """
    Information about a VNIC that belongs to a network security group.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NetworkSecurityGroupVnic object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_id:
            The value to assign to the resource_id property of this NetworkSecurityGroupVnic.
        :type resource_id: str

        :param time_associated:
            The value to assign to the time_associated property of this NetworkSecurityGroupVnic.
        :type time_associated: datetime

        :param vnic_id:
            The value to assign to the vnic_id property of this NetworkSecurityGroupVnic.
        :type vnic_id: str

        """
        self.swagger_types = {
            'resource_id': 'str',
            'time_associated': 'datetime',
            'vnic_id': 'str'
        }

        self.attribute_map = {
            'resource_id': 'resourceId',
            'time_associated': 'timeAssociated',
            'vnic_id': 'vnicId'
        }

        self._resource_id = None
        self._time_associated = None
        self._vnic_id = None

    @property
    def resource_id(self):
        """
        Gets the resource_id of this NetworkSecurityGroupVnic.
        The `OCID`__ of the parent resource that the VNIC
        is attached to (for example, a Compute instance).

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The resource_id of this NetworkSecurityGroupVnic.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this NetworkSecurityGroupVnic.
        The `OCID`__ of the parent resource that the VNIC
        is attached to (for example, a Compute instance).

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param resource_id: The resource_id of this NetworkSecurityGroupVnic.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def time_associated(self):
        """
        Gets the time_associated of this NetworkSecurityGroupVnic.
        The date and time the VNIC was added to the network security group, in the format
        defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_associated of this NetworkSecurityGroupVnic.
        :rtype: datetime
        """
        return self._time_associated

    @time_associated.setter
    def time_associated(self, time_associated):
        """
        Sets the time_associated of this NetworkSecurityGroupVnic.
        The date and time the VNIC was added to the network security group, in the format
        defined by `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_associated: The time_associated of this NetworkSecurityGroupVnic.
        :type: datetime
        """
        self._time_associated = time_associated

    @property
    def vnic_id(self):
        """
        **[Required]** Gets the vnic_id of this NetworkSecurityGroupVnic.
        The `OCID`__ of the VNIC.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The vnic_id of this NetworkSecurityGroupVnic.
        :rtype: str
        """
        return self._vnic_id

    @vnic_id.setter
    def vnic_id(self, vnic_id):
        """
        Sets the vnic_id of this NetworkSecurityGroupVnic.
        The `OCID`__ of the VNIC.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param vnic_id: The vnic_id of this NetworkSecurityGroupVnic.
        :type: str
        """
        self._vnic_id = vnic_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseHomeMetricDefinition(object):
    """
    The response containing the CPU, Storage, Wait, DB Time, and Memory metrics for a specific database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseHomeMetricDefinition object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param activity_time_series_metrics:
            The value to assign to the activity_time_series_metrics property of this DatabaseHomeMetricDefinition.
        :type activity_time_series_metrics: list[oci.database_management.models.ActivityTimeSeriesMetrics]

        :param db_time_aggregate_metrics:
            The value to assign to the db_time_aggregate_metrics property of this DatabaseHomeMetricDefinition.
        :type db_time_aggregate_metrics: oci.database_management.models.DatabaseTimeAggregateMetrics

        :param io_aggregate_metrics:
            The value to assign to the io_aggregate_metrics property of this DatabaseHomeMetricDefinition.
        :type io_aggregate_metrics: oci.database_management.models.DatabaseIOAggregateMetrics

        :param memory_aggregate_metrics:
            The value to assign to the memory_aggregate_metrics property of this DatabaseHomeMetricDefinition.
        :type memory_aggregate_metrics: oci.database_management.models.MemoryAggregateMetrics

        :param db_storage_aggregate_metrics:
            The value to assign to the db_storage_aggregate_metrics property of this DatabaseHomeMetricDefinition.
        :type db_storage_aggregate_metrics: oci.database_management.models.DatabaseStorageAggregateMetrics

        """
        self.swagger_types = {
            'activity_time_series_metrics': 'list[ActivityTimeSeriesMetrics]',
            'db_time_aggregate_metrics': 'DatabaseTimeAggregateMetrics',
            'io_aggregate_metrics': 'DatabaseIOAggregateMetrics',
            'memory_aggregate_metrics': 'MemoryAggregateMetrics',
            'db_storage_aggregate_metrics': 'DatabaseStorageAggregateMetrics'
        }

        self.attribute_map = {
            'activity_time_series_metrics': 'activityTimeSeriesMetrics',
            'db_time_aggregate_metrics': 'dbTimeAggregateMetrics',
            'io_aggregate_metrics': 'ioAggregateMetrics',
            'memory_aggregate_metrics': 'memoryAggregateMetrics',
            'db_storage_aggregate_metrics': 'dbStorageAggregateMetrics'
        }

        self._activity_time_series_metrics = None
        self._db_time_aggregate_metrics = None
        self._io_aggregate_metrics = None
        self._memory_aggregate_metrics = None
        self._db_storage_aggregate_metrics = None

    @property
    def activity_time_series_metrics(self):
        """
        **[Required]** Gets the activity_time_series_metrics of this DatabaseHomeMetricDefinition.
        A list of the active session metrics for CPU and Wait time for a specific database.


        :return: The activity_time_series_metrics of this DatabaseHomeMetricDefinition.
        :rtype: list[oci.database_management.models.ActivityTimeSeriesMetrics]
        """
        return self._activity_time_series_metrics

    @activity_time_series_metrics.setter
    def activity_time_series_metrics(self, activity_time_series_metrics):
        """
        Sets the activity_time_series_metrics of this DatabaseHomeMetricDefinition.
        A list of the active session metrics for CPU and Wait time for a specific database.


        :param activity_time_series_metrics: The activity_time_series_metrics of this DatabaseHomeMetricDefinition.
        :type: list[oci.database_management.models.ActivityTimeSeriesMetrics]
        """
        self._activity_time_series_metrics = activity_time_series_metrics

    @property
    def db_time_aggregate_metrics(self):
        """
        **[Required]** Gets the db_time_aggregate_metrics of this DatabaseHomeMetricDefinition.

        :return: The db_time_aggregate_metrics of this DatabaseHomeMetricDefinition.
        :rtype: oci.database_management.models.DatabaseTimeAggregateMetrics
        """
        return self._db_time_aggregate_metrics

    @db_time_aggregate_metrics.setter
    def db_time_aggregate_metrics(self, db_time_aggregate_metrics):
        """
        Sets the db_time_aggregate_metrics of this DatabaseHomeMetricDefinition.

        :param db_time_aggregate_metrics: The db_time_aggregate_metrics of this DatabaseHomeMetricDefinition.
        :type: oci.database_management.models.DatabaseTimeAggregateMetrics
        """
        self._db_time_aggregate_metrics = db_time_aggregate_metrics

    @property
    def io_aggregate_metrics(self):
        """
        **[Required]** Gets the io_aggregate_metrics of this DatabaseHomeMetricDefinition.

        :return: The io_aggregate_metrics of this DatabaseHomeMetricDefinition.
        :rtype: oci.database_management.models.DatabaseIOAggregateMetrics
        """
        return self._io_aggregate_metrics

    @io_aggregate_metrics.setter
    def io_aggregate_metrics(self, io_aggregate_metrics):
        """
        Sets the io_aggregate_metrics of this DatabaseHomeMetricDefinition.

        :param io_aggregate_metrics: The io_aggregate_metrics of this DatabaseHomeMetricDefinition.
        :type: oci.database_management.models.DatabaseIOAggregateMetrics
        """
        self._io_aggregate_metrics = io_aggregate_metrics

    @property
    def memory_aggregate_metrics(self):
        """
        **[Required]** Gets the memory_aggregate_metrics of this DatabaseHomeMetricDefinition.

        :return: The memory_aggregate_metrics of this DatabaseHomeMetricDefinition.
        :rtype: oci.database_management.models.MemoryAggregateMetrics
        """
        return self._memory_aggregate_metrics

    @memory_aggregate_metrics.setter
    def memory_aggregate_metrics(self, memory_aggregate_metrics):
        """
        Sets the memory_aggregate_metrics of this DatabaseHomeMetricDefinition.

        :param memory_aggregate_metrics: The memory_aggregate_metrics of this DatabaseHomeMetricDefinition.
        :type: oci.database_management.models.MemoryAggregateMetrics
        """
        self._memory_aggregate_metrics = memory_aggregate_metrics

    @property
    def db_storage_aggregate_metrics(self):
        """
        **[Required]** Gets the db_storage_aggregate_metrics of this DatabaseHomeMetricDefinition.

        :return: The db_storage_aggregate_metrics of this DatabaseHomeMetricDefinition.
        :rtype: oci.database_management.models.DatabaseStorageAggregateMetrics
        """
        return self._db_storage_aggregate_metrics

    @db_storage_aggregate_metrics.setter
    def db_storage_aggregate_metrics(self, db_storage_aggregate_metrics):
        """
        Sets the db_storage_aggregate_metrics of this DatabaseHomeMetricDefinition.

        :param db_storage_aggregate_metrics: The db_storage_aggregate_metrics of this DatabaseHomeMetricDefinition.
        :type: oci.database_management.models.DatabaseStorageAggregateMetrics
        """
        self._db_storage_aggregate_metrics = db_storage_aggregate_metrics

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateVcnDetails(object):
    """
    CreateVcnDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateVcnDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param cidr_block:
            The value to assign to the cidr_block property of this CreateVcnDetails.
        :type cidr_block: str

        :param cidr_blocks:
            The value to assign to the cidr_blocks property of this CreateVcnDetails.
        :type cidr_blocks: list[str]

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateVcnDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateVcnDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this CreateVcnDetails.
        :type display_name: str

        :param dns_label:
            The value to assign to the dns_label property of this CreateVcnDetails.
        :type dns_label: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateVcnDetails.
        :type freeform_tags: dict(str, str)

        :param is_ipv6_enabled:
            The value to assign to the is_ipv6_enabled property of this CreateVcnDetails.
        :type is_ipv6_enabled: bool

        """
        self.swagger_types = {
            'cidr_block': 'str',
            'cidr_blocks': 'list[str]',
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'dns_label': 'str',
            'freeform_tags': 'dict(str, str)',
            'is_ipv6_enabled': 'bool'
        }

        self.attribute_map = {
            'cidr_block': 'cidrBlock',
            'cidr_blocks': 'cidrBlocks',
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'dns_label': 'dnsLabel',
            'freeform_tags': 'freeformTags',
            'is_ipv6_enabled': 'isIpv6Enabled'
        }

        self._cidr_block = None
        self._cidr_blocks = None
        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._dns_label = None
        self._freeform_tags = None
        self._is_ipv6_enabled = None

    @property
    def cidr_block(self):
        """
        Gets the cidr_block of this CreateVcnDetails.
        **Deprecated.** Do *not* set this value. Use `cidrBlocks` instead.
        Example: `10.0.0.0/16`


        :return: The cidr_block of this CreateVcnDetails.
        :rtype: str
        """
        return self._cidr_block

    @cidr_block.setter
    def cidr_block(self, cidr_block):
        """
        Sets the cidr_block of this CreateVcnDetails.
        **Deprecated.** Do *not* set this value. Use `cidrBlocks` instead.
        Example: `10.0.0.0/16`


        :param cidr_block: The cidr_block of this CreateVcnDetails.
        :type: str
        """
        self._cidr_block = cidr_block

    @property
    def cidr_blocks(self):
        """
        Gets the cidr_blocks of this CreateVcnDetails.
        The list of one or more IPv4 CIDR blocks for the VCN that meet the following criteria:
        - The CIDR blocks must be valid.
        - They must not overlap with each other or with the on-premises network CIDR block.
        - The number of CIDR blocks must not exceed the limit of CIDR blocks allowed per VCN.

        **Important:** Do *not* specify a value for `cidrBlock`. Use this parameter instead.


        :return: The cidr_blocks of this CreateVcnDetails.
        :rtype: list[str]
        """
        return self._cidr_blocks

    @cidr_blocks.setter
    def cidr_blocks(self, cidr_blocks):
        """
        Sets the cidr_blocks of this CreateVcnDetails.
        The list of one or more IPv4 CIDR blocks for the VCN that meet the following criteria:
        - The CIDR blocks must be valid.
        - They must not overlap with each other or with the on-premises network CIDR block.
        - The number of CIDR blocks must not exceed the limit of CIDR blocks allowed per VCN.

        **Important:** Do *not* specify a value for `cidrBlock`. Use this parameter instead.


        :param cidr_blocks: The cidr_blocks of this CreateVcnDetails.
        :type: list[str]
        """
        self._cidr_blocks = cidr_blocks

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateVcnDetails.
        The OCID of the compartment to contain the VCN.


        :return: The compartment_id of this CreateVcnDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateVcnDetails.
        The OCID of the compartment to contain the VCN.


        :param compartment_id: The compartment_id of this CreateVcnDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateVcnDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateVcnDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateVcnDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateVcnDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateVcnDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this CreateVcnDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateVcnDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this CreateVcnDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def dns_label(self):
        """
        Gets the dns_label of this CreateVcnDetails.
        A DNS label for the VCN, used in conjunction with the VNIC's hostname and
        subnet's DNS label to form a fully qualified domain name (FQDN) for each VNIC
        within this subnet (for example, `bminstance-1.subnet123.vcn1.oraclevcn.com`).
        Not required to be unique, but it's a best practice to set unique DNS labels
        for VCNs in your tenancy. Must be an alphanumeric string that begins with a letter.
        The value cannot be changed.

        You must set this value if you want instances to be able to use hostnames to
        resolve other instances in the VCN. Otherwise the Internet and VCN Resolver
        will not work.

        For more information, see
        `DNS in Your Virtual Cloud Network`__.

        Example: `vcn1`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm


        :return: The dns_label of this CreateVcnDetails.
        :rtype: str
        """
        return self._dns_label

    @dns_label.setter
    def dns_label(self, dns_label):
        """
        Sets the dns_label of this CreateVcnDetails.
        A DNS label for the VCN, used in conjunction with the VNIC's hostname and
        subnet's DNS label to form a fully qualified domain name (FQDN) for each VNIC
        within this subnet (for example, `bminstance-1.subnet123.vcn1.oraclevcn.com`).
        Not required to be unique, but it's a best practice to set unique DNS labels
        for VCNs in your tenancy. Must be an alphanumeric string that begins with a letter.
        The value cannot be changed.

        You must set this value if you want instances to be able to use hostnames to
        resolve other instances in the VCN. Otherwise the Internet and VCN Resolver
        will not work.

        For more information, see
        `DNS in Your Virtual Cloud Network`__.

        Example: `vcn1`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm


        :param dns_label: The dns_label of this CreateVcnDetails.
        :type: str
        """
        self._dns_label = dns_label

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateVcnDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateVcnDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateVcnDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateVcnDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def is_ipv6_enabled(self):
        """
        Gets the is_ipv6_enabled of this CreateVcnDetails.
        Whether IPv6 is enabled for the VCN. Default is `false`.
        If enabled, Oracle will assign the VCN a IPv6 /56 CIDR block.
        For important details about IPv6 addressing in a VCN, see `IPv6 Addresses`__.

        Example: `true`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :return: The is_ipv6_enabled of this CreateVcnDetails.
        :rtype: bool
        """
        return self._is_ipv6_enabled

    @is_ipv6_enabled.setter
    def is_ipv6_enabled(self, is_ipv6_enabled):
        """
        Sets the is_ipv6_enabled of this CreateVcnDetails.
        Whether IPv6 is enabled for the VCN. Default is `false`.
        If enabled, Oracle will assign the VCN a IPv6 /56 CIDR block.
        For important details about IPv6 addressing in a VCN, see `IPv6 Addresses`__.

        Example: `true`

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/ipv6.htm


        :param is_ipv6_enabled: The is_ipv6_enabled of this CreateVcnDetails.
        :type: bool
        """
        self._is_ipv6_enabled = is_ipv6_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ProtectionRuleExclusion(object):
    """
    Allows specified types of requests to bypass the protection rule. If a request matches any of the criteria in the `exclusions` field, the protection rule will not be executed. Rules can have more than one exclusion and exclusions are applied to requests disjunctively, meaning the specified exclusion strings are independently matched against the specified targets of a request. The first target to match a specified string will trigger an exclusion. **Example:** If the following exclusions are defined for a protection rule:

    \"action\": \"BLOCK\",
    \"exclusions\": [
    {
    \"target\":\"REQUEST_COOKIES\",
    \"exclusions\":[\"example.com\", \"12345\", \"219ffwef9w0f\"]
    },
    {
    \"target\":\"REQUEST_COOKIE_NAMES\",
    \"exclusions\":[\"OAMAuthnCookie\", \"JSESSIONID\", \"HCM-PSJSESSIONID\"]
    }
    ],
    \"key\": \"1000000\",

    A request with the cookie name `sessionid` would trigger an exclusion. A request with the cookie name `yourcompany.com` would *not* trigger and exclusion.
    """

    #: A constant which can be used with the target property of a ProtectionRuleExclusion.
    #: This constant has a value of "REQUEST_COOKIES"
    TARGET_REQUEST_COOKIES = "REQUEST_COOKIES"

    #: A constant which can be used with the target property of a ProtectionRuleExclusion.
    #: This constant has a value of "REQUEST_COOKIE_NAMES"
    TARGET_REQUEST_COOKIE_NAMES = "REQUEST_COOKIE_NAMES"

    #: A constant which can be used with the target property of a ProtectionRuleExclusion.
    #: This constant has a value of "ARGS"
    TARGET_ARGS = "ARGS"

    #: A constant which can be used with the target property of a ProtectionRuleExclusion.
    #: This constant has a value of "ARGS_NAMES"
    TARGET_ARGS_NAMES = "ARGS_NAMES"

    def __init__(self, **kwargs):
        """
        Initializes a new ProtectionRuleExclusion object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param target:
            The value to assign to the target property of this ProtectionRuleExclusion.
            Allowed values for this property are: "REQUEST_COOKIES", "REQUEST_COOKIE_NAMES", "ARGS", "ARGS_NAMES", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type target: str

        :param exclusions:
            The value to assign to the exclusions property of this ProtectionRuleExclusion.
        :type exclusions: list[str]

        """
        self.swagger_types = {
            'target': 'str',
            'exclusions': 'list[str]'
        }

        self.attribute_map = {
            'target': 'target',
            'exclusions': 'exclusions'
        }

        self._target = None
        self._exclusions = None

    @property
    def target(self):
        """
        Gets the target of this ProtectionRuleExclusion.
        The target of the exclusion.

        Allowed values for this property are: "REQUEST_COOKIES", "REQUEST_COOKIE_NAMES", "ARGS", "ARGS_NAMES", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The target of this ProtectionRuleExclusion.
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this ProtectionRuleExclusion.
        The target of the exclusion.


        :param target: The target of this ProtectionRuleExclusion.
        :type: str
        """
        allowed_values = ["REQUEST_COOKIES", "REQUEST_COOKIE_NAMES", "ARGS", "ARGS_NAMES"]
        if not value_allowed_none_or_none_sentinel(target, allowed_values):
            target = 'UNKNOWN_ENUM_VALUE'
        self._target = target

    @property
    def exclusions(self):
        """
        Gets the exclusions of this ProtectionRuleExclusion.

        :return: The exclusions of this ProtectionRuleExclusion.
        :rtype: list[str]
        """
        return self._exclusions

    @exclusions.setter
    def exclusions(self, exclusions):
        """
        Sets the exclusions of this ProtectionRuleExclusion.

        :param exclusions: The exclusions of this ProtectionRuleExclusion.
        :type: list[str]
        """
        self._exclusions = exclusions

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JobRunSummary(object):
    """
    A summary of a specific job run.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JobRunSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this JobRunSummary.
        :type id: str

        :param name:
            The value to assign to the name property of this JobRunSummary.
        :type name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this JobRunSummary.
        :type compartment_id: str

        :param job_id:
            The value to assign to the job_id property of this JobRunSummary.
        :type job_id: str

        :param job_name:
            The value to assign to the job_name property of this JobRunSummary.
        :type job_name: str

        :param managed_database_group_id:
            The value to assign to the managed_database_group_id property of this JobRunSummary.
        :type managed_database_group_id: str

        :param managed_database_id:
            The value to assign to the managed_database_id property of this JobRunSummary.
        :type managed_database_id: str

        :param run_status:
            The value to assign to the run_status property of this JobRunSummary.
        :type run_status: str

        :param time_submitted:
            The value to assign to the time_submitted property of this JobRunSummary.
        :type time_submitted: datetime

        :param time_updated:
            The value to assign to the time_updated property of this JobRunSummary.
        :type time_updated: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'compartment_id': 'str',
            'job_id': 'str',
            'job_name': 'str',
            'managed_database_group_id': 'str',
            'managed_database_id': 'str',
            'run_status': 'str',
            'time_submitted': 'datetime',
            'time_updated': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'compartment_id': 'compartmentId',
            'job_id': 'jobId',
            'job_name': 'jobName',
            'managed_database_group_id': 'managedDatabaseGroupId',
            'managed_database_id': 'managedDatabaseId',
            'run_status': 'runStatus',
            'time_submitted': 'timeSubmitted',
            'time_updated': 'timeUpdated'
        }

        self._id = None
        self._name = None
        self._compartment_id = None
        self._job_id = None
        self._job_name = None
        self._managed_database_group_id = None
        self._managed_database_id = None
        self._run_status = None
        self._time_submitted = None
        self._time_updated = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this JobRunSummary.
        The identifier of the job run.


        :return: The id of this JobRunSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this JobRunSummary.
        The identifier of the job run.


        :param id: The id of this JobRunSummary.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        **[Required]** Gets the name of this JobRunSummary.
        The name of the job run.


        :return: The name of this JobRunSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this JobRunSummary.
        The name of the job run.


        :param name: The name of this JobRunSummary.
        :type: str
        """
        self._name = name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this JobRunSummary.
        The `OCID`__ of the compartment in which the parent job resides.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this JobRunSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this JobRunSummary.
        The `OCID`__ of the compartment in which the parent job resides.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this JobRunSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def job_id(self):
        """
        **[Required]** Gets the job_id of this JobRunSummary.
        The `OCID`__ of the parent job.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The job_id of this JobRunSummary.
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """
        Sets the job_id of this JobRunSummary.
        The `OCID`__ of the parent job.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param job_id: The job_id of this JobRunSummary.
        :type: str
        """
        self._job_id = job_id

    @property
    def job_name(self):
        """
        **[Required]** Gets the job_name of this JobRunSummary.
        The name of the parent job.


        :return: The job_name of this JobRunSummary.
        :rtype: str
        """
        return self._job_name

    @job_name.setter
    def job_name(self, job_name):
        """
        Sets the job_name of this JobRunSummary.
        The name of the parent job.


        :param job_name: The job_name of this JobRunSummary.
        :type: str
        """
        self._job_name = job_name

    @property
    def managed_database_group_id(self):
        """
        Gets the managed_database_group_id of this JobRunSummary.
        The `OCID`__ of the Managed Database Group where the parent job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The managed_database_group_id of this JobRunSummary.
        :rtype: str
        """
        return self._managed_database_group_id

    @managed_database_group_id.setter
    def managed_database_group_id(self, managed_database_group_id):
        """
        Sets the managed_database_group_id of this JobRunSummary.
        The `OCID`__ of the Managed Database Group where the parent job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param managed_database_group_id: The managed_database_group_id of this JobRunSummary.
        :type: str
        """
        self._managed_database_group_id = managed_database_group_id

    @property
    def managed_database_id(self):
        """
        Gets the managed_database_id of this JobRunSummary.
        The `OCID`__ of the Managed Database where the parent job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The managed_database_id of this JobRunSummary.
        :rtype: str
        """
        return self._managed_database_id

    @managed_database_id.setter
    def managed_database_id(self, managed_database_id):
        """
        Sets the managed_database_id of this JobRunSummary.
        The `OCID`__ of the Managed Database where the parent job has to be executed.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param managed_database_id: The managed_database_id of this JobRunSummary.
        :type: str
        """
        self._managed_database_id = managed_database_id

    @property
    def run_status(self):
        """
        **[Required]** Gets the run_status of this JobRunSummary.
        The status of the job run.


        :return: The run_status of this JobRunSummary.
        :rtype: str
        """
        return self._run_status

    @run_status.setter
    def run_status(self, run_status):
        """
        Sets the run_status of this JobRunSummary.
        The status of the job run.


        :param run_status: The run_status of this JobRunSummary.
        :type: str
        """
        self._run_status = run_status

    @property
    def time_submitted(self):
        """
        **[Required]** Gets the time_submitted of this JobRunSummary.
        The date and time when the job run was submitted.


        :return: The time_submitted of this JobRunSummary.
        :rtype: datetime
        """
        return self._time_submitted

    @time_submitted.setter
    def time_submitted(self, time_submitted):
        """
        Sets the time_submitted of this JobRunSummary.
        The date and time when the job run was submitted.


        :param time_submitted: The time_submitted of this JobRunSummary.
        :type: datetime
        """
        self._time_submitted = time_submitted

    @property
    def time_updated(self):
        """
        **[Required]** Gets the time_updated of this JobRunSummary.
        The date and time when the job run was last updated.


        :return: The time_updated of this JobRunSummary.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this JobRunSummary.
        The date and time when the job run was last updated.


        :param time_updated: The time_updated of this JobRunSummary.
        :type: datetime
        """
        self._time_updated = time_updated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TagDefault(object):
    """
    Tag defaults let you specify a default tag (tagnamespace.tag=\"value\") to apply to all resource types
    in a specified compartment. The tag default is applied at the time the resource is created. Resources
    that exist in the compartment before you create the tag default are not tagged. The `TagDefault` object
    specifies the tag and compartment details.

    Tag defaults are inherited by child compartments. This means that if you set a tag default on the root compartment
    for a tenancy, all resources that are created in the tenancy are tagged. For more information about
    using tag defaults, see `Managing Tag Defaults`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator.

    __ https://docs.cloud.oracle.com/Content/Identity/Tasks/managingtagdefaults.htm
    """

    #: A constant which can be used with the lifecycle_state property of a TagDefault.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new TagDefault object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this TagDefault.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this TagDefault.
        :type compartment_id: str

        :param tag_namespace_id:
            The value to assign to the tag_namespace_id property of this TagDefault.
        :type tag_namespace_id: str

        :param tag_definition_id:
            The value to assign to the tag_definition_id property of this TagDefault.
        :type tag_definition_id: str

        :param tag_definition_name:
            The value to assign to the tag_definition_name property of this TagDefault.
        :type tag_definition_name: str

        :param value:
            The value to assign to the value property of this TagDefault.
        :type value: str

        :param time_created:
            The value to assign to the time_created property of this TagDefault.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this TagDefault.
            Allowed values for this property are: "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param is_required:
            The value to assign to the is_required property of this TagDefault.
        :type is_required: bool

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'tag_namespace_id': 'str',
            'tag_definition_id': 'str',
            'tag_definition_name': 'str',
            'value': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'is_required': 'bool'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'tag_namespace_id': 'tagNamespaceId',
            'tag_definition_id': 'tagDefinitionId',
            'tag_definition_name': 'tagDefinitionName',
            'value': 'value',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'is_required': 'isRequired'
        }

        self._id = None
        self._compartment_id = None
        self._tag_namespace_id = None
        self._tag_definition_id = None
        self._tag_definition_name = None
        self._value = None
        self._time_created = None
        self._lifecycle_state = None
        self._is_required = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this TagDefault.
        The OCID of the tag default.


        :return: The id of this TagDefault.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TagDefault.
        The OCID of the tag default.


        :param id: The id of this TagDefault.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this TagDefault.
        The OCID of the compartment. The tag default applies to all new resources that get created in the
        compartment. Resources that existed before the tag default was created are not tagged.


        :return: The compartment_id of this TagDefault.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this TagDefault.
        The OCID of the compartment. The tag default applies to all new resources that get created in the
        compartment. Resources that existed before the tag default was created are not tagged.


        :param compartment_id: The compartment_id of this TagDefault.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def tag_namespace_id(self):
        """
        **[Required]** Gets the tag_namespace_id of this TagDefault.
        The OCID of the tag namespace that contains the tag definition.


        :return: The tag_namespace_id of this TagDefault.
        :rtype: str
        """
        return self._tag_namespace_id

    @tag_namespace_id.setter
    def tag_namespace_id(self, tag_namespace_id):
        """
        Sets the tag_namespace_id of this TagDefault.
        The OCID of the tag namespace that contains the tag definition.


        :param tag_namespace_id: The tag_namespace_id of this TagDefault.
        :type: str
        """
        self._tag_namespace_id = tag_namespace_id

    @property
    def tag_definition_id(self):
        """
        **[Required]** Gets the tag_definition_id of this TagDefault.
        The OCID of the tag definition. The tag default will always assign a default value for this tag definition.


        :return: The tag_definition_id of this TagDefault.
        :rtype: str
        """
        return self._tag_definition_id

    @tag_definition_id.setter
    def tag_definition_id(self, tag_definition_id):
        """
        Sets the tag_definition_id of this TagDefault.
        The OCID of the tag definition. The tag default will always assign a default value for this tag definition.


        :param tag_definition_id: The tag_definition_id of this TagDefault.
        :type: str
        """
        self._tag_definition_id = tag_definition_id

    @property
    def tag_definition_name(self):
        """
        **[Required]** Gets the tag_definition_name of this TagDefault.
        The name used in the tag definition. This field is informational in the context of the tag default.


        :return: The tag_definition_name of this TagDefault.
        :rtype: str
        """
        return self._tag_definition_name

    @tag_definition_name.setter
    def tag_definition_name(self, tag_definition_name):
        """
        Sets the tag_definition_name of this TagDefault.
        The name used in the tag definition. This field is informational in the context of the tag default.


        :param tag_definition_name: The tag_definition_name of this TagDefault.
        :type: str
        """
        self._tag_definition_name = tag_definition_name

    @property
    def value(self):
        """
        **[Required]** Gets the value of this TagDefault.
        The default value for the tag definition. This will be applied to all resources created in the compartment.


        :return: The value of this TagDefault.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this TagDefault.
        The default value for the tag definition. This will be applied to all resources created in the compartment.


        :param value: The value of this TagDefault.
        :type: str
        """
        self._value = value

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this TagDefault.
        Date and time the `TagDefault` object was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :return: The time_created of this TagDefault.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this TagDefault.
        Date and time the `TagDefault` object was created, in the format defined by RFC3339.

        Example: `2016-08-25T21:10:29.600Z`


        :param time_created: The time_created of this TagDefault.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this TagDefault.
        The tag default's current state. After creating a `TagDefault`, make sure its `lifecycleState` is ACTIVE before using it.

        Allowed values for this property are: "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this TagDefault.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this TagDefault.
        The tag default's current state. After creating a `TagDefault`, make sure its `lifecycleState` is ACTIVE before using it.


        :param lifecycle_state: The lifecycle_state of this TagDefault.
        :type: str
        """
        allowed_values = ["ACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def is_required(self):
        """
        **[Required]** Gets the is_required of this TagDefault.
        If you specify that a value is required, a value is set during resource creation (either by the
        user creating the resource or another tag defualt). If no value is set, resource creation is
        blocked.

        * If the `isRequired` flag is set to \"true\", the value is set during resource creation.
        * If the `isRequired` flag is set to \"false\", the value you enter is set during resource creation.

        Example: `false`


        :return: The is_required of this TagDefault.
        :rtype: bool
        """
        return self._is_required

    @is_required.setter
    def is_required(self, is_required):
        """
        Sets the is_required of this TagDefault.
        If you specify that a value is required, a value is set during resource creation (either by the
        user creating the resource or another tag defualt). If no value is set, resource creation is
        blocked.

        * If the `isRequired` flag is set to \"true\", the value is set during resource creation.
        * If the `isRequired` flag is set to \"false\", the value you enter is set during resource creation.

        Example: `false`


        :param is_required: The is_required of this TagDefault.
        :type: bool
        """
        self._is_required = is_required

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectLifecycleRule(object):
    """
    To use any of the API operations, you must be authorized in an IAM policy. If you are not authorized,
    talk to an administrator. If you are an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the time_unit property of a ObjectLifecycleRule.
    #: This constant has a value of "DAYS"
    TIME_UNIT_DAYS = "DAYS"

    #: A constant which can be used with the time_unit property of a ObjectLifecycleRule.
    #: This constant has a value of "YEARS"
    TIME_UNIT_YEARS = "YEARS"

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectLifecycleRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ObjectLifecycleRule.
        :type name: str

        :param target:
            The value to assign to the target property of this ObjectLifecycleRule.
        :type target: str

        :param action:
            The value to assign to the action property of this ObjectLifecycleRule.
        :type action: str

        :param time_amount:
            The value to assign to the time_amount property of this ObjectLifecycleRule.
        :type time_amount: int

        :param time_unit:
            The value to assign to the time_unit property of this ObjectLifecycleRule.
            Allowed values for this property are: "DAYS", "YEARS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type time_unit: str

        :param is_enabled:
            The value to assign to the is_enabled property of this ObjectLifecycleRule.
        :type is_enabled: bool

        :param object_name_filter:
            The value to assign to the object_name_filter property of this ObjectLifecycleRule.
        :type object_name_filter: oci.object_storage.models.ObjectNameFilter

        """
        self.swagger_types = {
            'name': 'str',
            'target': 'str',
            'action': 'str',
            'time_amount': 'int',
            'time_unit': 'str',
            'is_enabled': 'bool',
            'object_name_filter': 'ObjectNameFilter'
        }

        self.attribute_map = {
            'name': 'name',
            'target': 'target',
            'action': 'action',
            'time_amount': 'timeAmount',
            'time_unit': 'timeUnit',
            'is_enabled': 'isEnabled',
            'object_name_filter': 'objectNameFilter'
        }

        self._name = None
        self._target = None
        self._action = None
        self._time_amount = None
        self._time_unit = None
        self._is_enabled = None
        self._object_name_filter = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ObjectLifecycleRule.
        The name of the lifecycle rule to be applied.


        :return: The name of this ObjectLifecycleRule.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ObjectLifecycleRule.
        The name of the lifecycle rule to be applied.


        :param name: The name of this ObjectLifecycleRule.
        :type: str
        """
        self._name = name

    @property
    def target(self):
        """
        Gets the target of this ObjectLifecycleRule.
        The target of the object lifecycle policy rule. The values of target can be either \"objects\",
        \"multipart-uploads\" or \"previous-object-versions\".
        This field when declared as \"objects\" is used to specify ARCHIVE, INFREQUENT_ACCESS
        or DELETE rule for objects.
        This field when declared as \"previous-object-versions\" is used to specify ARCHIVE,
        INFREQUENT_ACCESS or DELETE rule for previous versions of existing objects.
        This field when declared as \"multipart-uploads\" is used to specify the ABORT (only) rule for
        uncommitted multipart-uploads.


        :return: The target of this ObjectLifecycleRule.
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """
        Sets the target of this ObjectLifecycleRule.
        The target of the object lifecycle policy rule. The values of target can be either \"objects\",
        \"multipart-uploads\" or \"previous-object-versions\".
        This field when declared as \"objects\" is used to specify ARCHIVE, INFREQUENT_ACCESS
        or DELETE rule for objects.
        This field when declared as \"previous-object-versions\" is used to specify ARCHIVE,
        INFREQUENT_ACCESS or DELETE rule for previous versions of existing objects.
        This field when declared as \"multipart-uploads\" is used to specify the ABORT (only) rule for
        uncommitted multipart-uploads.


        :param target: The target of this ObjectLifecycleRule.
        :type: str
        """
        self._target = target

    @property
    def action(self):
        """
        **[Required]** Gets the action of this ObjectLifecycleRule.
        The action of the object lifecycle policy rule.
        Rules using the action 'ARCHIVE' move objects from Standard and InfrequentAccess storage tiers
        into the `Archive storage tier`__.
        Rules using the action 'INFREQUENT_ACCESS' move objects from Standard storage tier into the
        Infrequent Access Storage tier. Objects that are already in InfrequentAccess tier or in Archive
        tier are left untouched.
        Rules using the action 'DELETE' permanently delete objects from buckets.
        Rules using 'ABORT' abort the uncommitted multipart-uploads and permanently delete their parts from buckets.

        __ https://docs.cloud.oracle.com/Content/Archive/Concepts/archivestorageoverview.htm


        :return: The action of this ObjectLifecycleRule.
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """
        Sets the action of this ObjectLifecycleRule.
        The action of the object lifecycle policy rule.
        Rules using the action 'ARCHIVE' move objects from Standard and InfrequentAccess storage tiers
        into the `Archive storage tier`__.
        Rules using the action 'INFREQUENT_ACCESS' move objects from Standard storage tier into the
        Infrequent Access Storage tier. Objects that are already in InfrequentAccess tier or in Archive
        tier are left untouched.
        Rules using the action 'DELETE' permanently delete objects from buckets.
        Rules using 'ABORT' abort the uncommitted multipart-uploads and permanently delete their parts from buckets.

        __ https://docs.cloud.oracle.com/Content/Archive/Concepts/archivestorageoverview.htm


        :param action: The action of this ObjectLifecycleRule.
        :type: str
        """
        self._action = action

    @property
    def time_amount(self):
        """
        **[Required]** Gets the time_amount of this ObjectLifecycleRule.
        Specifies the age of objects to apply the rule to. The timeAmount is interpreted in units defined by the
        timeUnit parameter, and is calculated in relation to each object's Last-Modified time.


        :return: The time_amount of this ObjectLifecycleRule.
        :rtype: int
        """
        return self._time_amount

    @time_amount.setter
    def time_amount(self, time_amount):
        """
        Sets the time_amount of this ObjectLifecycleRule.
        Specifies the age of objects to apply the rule to. The timeAmount is interpreted in units defined by the
        timeUnit parameter, and is calculated in relation to each object's Last-Modified time.


        :param time_amount: The time_amount of this ObjectLifecycleRule.
        :type: int
        """
        self._time_amount = time_amount

    @property
    def time_unit(self):
        """
        **[Required]** Gets the time_unit of this ObjectLifecycleRule.
        The unit that should be used to interpret timeAmount.  Days are defined as starting and ending at midnight UTC.
        Years are defined as 365.2425 days long and likewise round up to the next midnight UTC.

        Allowed values for this property are: "DAYS", "YEARS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The time_unit of this ObjectLifecycleRule.
        :rtype: str
        """
        return self._time_unit

    @time_unit.setter
    def time_unit(self, time_unit):
        """
        Sets the time_unit of this ObjectLifecycleRule.
        The unit that should be used to interpret timeAmount.  Days are defined as starting and ending at midnight UTC.
        Years are defined as 365.2425 days long and likewise round up to the next midnight UTC.


        :param time_unit: The time_unit of this ObjectLifecycleRule.
        :type: str
        """
        allowed_values = ["DAYS", "YEARS"]
        if not value_allowed_none_or_none_sentinel(time_unit, allowed_values):
            time_unit = 'UNKNOWN_ENUM_VALUE'
        self._time_unit = time_unit

    @property
    def is_enabled(self):
        """
        **[Required]** Gets the is_enabled of this ObjectLifecycleRule.
        A Boolean that determines whether this rule is currently enabled.


        :return: The is_enabled of this ObjectLifecycleRule.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this ObjectLifecycleRule.
        A Boolean that determines whether this rule is currently enabled.


        :param is_enabled: The is_enabled of this ObjectLifecycleRule.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def object_name_filter(self):
        """
        Gets the object_name_filter of this ObjectLifecycleRule.

        :return: The object_name_filter of this ObjectLifecycleRule.
        :rtype: oci.object_storage.models.ObjectNameFilter
        """
        return self._object_name_filter

    @object_name_filter.setter
    def object_name_filter(self, object_name_filter):
        """
        Sets the object_name_filter of this ObjectLifecycleRule.

        :param object_name_filter: The object_name_filter of this ObjectLifecycleRule.
        :type: oci.object_storage.models.ObjectNameFilter
        """
        self._object_name_filter = object_name_filter

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BaseAnnouncementsPreferences(object):
    """
    The object that contains the announcement email preferences configured for the tenancy (root compartment).
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BaseAnnouncementsPreferences object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.announcements_service.models.AnnouncementsPreferencesSummary`
        * :class:`~oci.announcements_service.models.AnnouncementsPreferences`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this BaseAnnouncementsPreferences.
        :type type: str

        :param compartment_id:
            The value to assign to the compartment_id property of this BaseAnnouncementsPreferences.
        :type compartment_id: str

        :param id:
            The value to assign to the id property of this BaseAnnouncementsPreferences.
        :type id: str

        :param is_unsubscribed:
            The value to assign to the is_unsubscribed property of this BaseAnnouncementsPreferences.
        :type is_unsubscribed: bool

        :param time_created:
            The value to assign to the time_created property of this BaseAnnouncementsPreferences.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this BaseAnnouncementsPreferences.
        :type time_updated: datetime

        :param preference_type:
            The value to assign to the preference_type property of this BaseAnnouncementsPreferences.
        :type preference_type: str

        """
        self.swagger_types = {
            'type': 'str',
            'compartment_id': 'str',
            'id': 'str',
            'is_unsubscribed': 'bool',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'preference_type': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'compartment_id': 'compartmentId',
            'id': 'id',
            'is_unsubscribed': 'isUnsubscribed',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'preference_type': 'preferenceType'
        }

        self._type = None
        self._compartment_id = None
        self._id = None
        self._is_unsubscribed = None
        self._time_created = None
        self._time_updated = None
        self._preference_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'AnnouncementsPreferencesSummary':
            return 'AnnouncementsPreferencesSummary'

        if type == 'AnnouncementsPreferences':
            return 'AnnouncementsPreferences'
        else:
            return 'BaseAnnouncementsPreferences'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this BaseAnnouncementsPreferences.
        The entity type, which specifies either an object or a summary object for announcement email preferences.


        :return: The type of this BaseAnnouncementsPreferences.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this BaseAnnouncementsPreferences.
        The entity type, which specifies either an object or a summary object for announcement email preferences.


        :param type: The type of this BaseAnnouncementsPreferences.
        :type: str
        """
        self._type = type

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this BaseAnnouncementsPreferences.
        The OCID of the compartment for which the email preferences apply. Because announcements are
        specific to a tenancy, specify the tenancy by providing the root compartment OCID.


        :return: The compartment_id of this BaseAnnouncementsPreferences.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this BaseAnnouncementsPreferences.
        The OCID of the compartment for which the email preferences apply. Because announcements are
        specific to a tenancy, specify the tenancy by providing the root compartment OCID.


        :param compartment_id: The compartment_id of this BaseAnnouncementsPreferences.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def id(self):
        """
        Gets the id of this BaseAnnouncementsPreferences.
        The ID of the preferences.


        :return: The id of this BaseAnnouncementsPreferences.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this BaseAnnouncementsPreferences.
        The ID of the preferences.


        :param id: The id of this BaseAnnouncementsPreferences.
        :type: str
        """
        self._id = id

    @property
    def is_unsubscribed(self):
        """
        Gets the is_unsubscribed of this BaseAnnouncementsPreferences.
        A Boolean value to indicate whether the specified compartment chooses to not to receive informational announcements by email.
        (Manage preferences for receiving announcements by email by specifying the `preferenceType` attribute instead.)


        :return: The is_unsubscribed of this BaseAnnouncementsPreferences.
        :rtype: bool
        """
        return self._is_unsubscribed

    @is_unsubscribed.setter
    def is_unsubscribed(self, is_unsubscribed):
        """
        Sets the is_unsubscribed of this BaseAnnouncementsPreferences.
        A Boolean value to indicate whether the specified compartment chooses to not to receive informational announcements by email.
        (Manage preferences for receiving announcements by email by specifying the `preferenceType` attribute instead.)


        :param is_unsubscribed: The is_unsubscribed of this BaseAnnouncementsPreferences.
        :type: bool
        """
        self._is_unsubscribed = is_unsubscribed

    @property
    def time_created(self):
        """
        Gets the time_created of this BaseAnnouncementsPreferences.
        When the preferences were set initially.


        :return: The time_created of this BaseAnnouncementsPreferences.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this BaseAnnouncementsPreferences.
        When the preferences were set initially.


        :param time_created: The time_created of this BaseAnnouncementsPreferences.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this BaseAnnouncementsPreferences.
        When the preferences were last updated.


        :return: The time_updated of this BaseAnnouncementsPreferences.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this BaseAnnouncementsPreferences.
        When the preferences were last updated.


        :param time_updated: The time_updated of this BaseAnnouncementsPreferences.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def preference_type(self):
        """
        Gets the preference_type of this BaseAnnouncementsPreferences.
        The string representing the user's preference regarding receiving announcements by email.


        :return: The preference_type of this BaseAnnouncementsPreferences.
        :rtype: str
        """
        return self._preference_type

    @preference_type.setter
    def preference_type(self, preference_type):
        """
        Sets the preference_type of this BaseAnnouncementsPreferences.
        The string representing the user's preference regarding receiving announcements by email.


        :param preference_type: The preference_type of this BaseAnnouncementsPreferences.
        :type: str
        """
        self._preference_type = preference_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LevelConfiguration(object):
    """
    Details about the configuration level for the recommendation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LevelConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param recommendation_id:
            The value to assign to the recommendation_id property of this LevelConfiguration.
        :type recommendation_id: str

        :param level:
            The value to assign to the level property of this LevelConfiguration.
        :type level: str

        """
        self.swagger_types = {
            'recommendation_id': 'str',
            'level': 'str'
        }

        self.attribute_map = {
            'recommendation_id': 'recommendationId',
            'level': 'level'
        }

        self._recommendation_id = None
        self._level = None

    @property
    def recommendation_id(self):
        """
        Gets the recommendation_id of this LevelConfiguration.
        The unique OCID of the recommendation.


        :return: The recommendation_id of this LevelConfiguration.
        :rtype: str
        """
        return self._recommendation_id

    @recommendation_id.setter
    def recommendation_id(self, recommendation_id):
        """
        Sets the recommendation_id of this LevelConfiguration.
        The unique OCID of the recommendation.


        :param recommendation_id: The recommendation_id of this LevelConfiguration.
        :type: str
        """
        self._recommendation_id = recommendation_id

    @property
    def level(self):
        """
        Gets the level of this LevelConfiguration.
        The pre-defined profile level.


        :return: The level of this LevelConfiguration.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this LevelConfiguration.
        The pre-defined profile level.


        :param level: The level of this LevelConfiguration.
        :type: str
        """
        self._level = level

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RoverNodeSummary(object):
    """
    Summary of the RoverNode.
    """

    #: A constant which can be used with the lifecycle_state property of a RoverNodeSummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a RoverNodeSummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a RoverNodeSummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a RoverNodeSummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a RoverNodeSummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a RoverNodeSummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new RoverNodeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this RoverNodeSummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this RoverNodeSummary.
        :type compartment_id: str

        :param cluster_id:
            The value to assign to the cluster_id property of this RoverNodeSummary.
        :type cluster_id: str

        :param serial_number:
            The value to assign to the serial_number property of this RoverNodeSummary.
        :type serial_number: str

        :param display_name:
            The value to assign to the display_name property of this RoverNodeSummary.
        :type display_name: str

        :param time_created:
            The value to assign to the time_created property of this RoverNodeSummary.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this RoverNodeSummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_state_details:
            The value to assign to the lifecycle_state_details property of this RoverNodeSummary.
        :type lifecycle_state_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this RoverNodeSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this RoverNodeSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this RoverNodeSummary.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'cluster_id': 'str',
            'serial_number': 'str',
            'display_name': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_state_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'cluster_id': 'clusterId',
            'serial_number': 'serialNumber',
            'display_name': 'displayName',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_state_details': 'lifecycleStateDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._compartment_id = None
        self._cluster_id = None
        self._serial_number = None
        self._display_name = None
        self._time_created = None
        self._lifecycle_state = None
        self._lifecycle_state_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this RoverNodeSummary.
        The OCID of the RoverNode.


        :return: The id of this RoverNodeSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RoverNodeSummary.
        The OCID of the RoverNode.


        :param id: The id of this RoverNodeSummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this RoverNodeSummary.
        The OCID of the compartment containing the RoverNode.


        :return: The compartment_id of this RoverNodeSummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this RoverNodeSummary.
        The OCID of the compartment containing the RoverNode.


        :param compartment_id: The compartment_id of this RoverNodeSummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def cluster_id(self):
        """
        Gets the cluster_id of this RoverNodeSummary.
        The cluster ID if the node is part of a cluster.


        :return: The cluster_id of this RoverNodeSummary.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """
        Sets the cluster_id of this RoverNodeSummary.
        The cluster ID if the node is part of a cluster.


        :param cluster_id: The cluster_id of this RoverNodeSummary.
        :type: str
        """
        self._cluster_id = cluster_id

    @property
    def serial_number(self):
        """
        Gets the serial_number of this RoverNodeSummary.
        Serial number of the node.


        :return: The serial_number of this RoverNodeSummary.
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """
        Sets the serial_number of this RoverNodeSummary.
        Serial number of the node.


        :param serial_number: The serial_number of this RoverNodeSummary.
        :type: str
        """
        self._serial_number = serial_number

    @property
    def display_name(self):
        """
        Gets the display_name of this RoverNodeSummary.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this RoverNodeSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this RoverNodeSummary.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this RoverNodeSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_created(self):
        """
        Gets the time_created of this RoverNodeSummary.
        The time the the RoverNode was created. An RFC3339 formatted datetime string


        :return: The time_created of this RoverNodeSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this RoverNodeSummary.
        The time the the RoverNode was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this RoverNodeSummary.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this RoverNodeSummary.
        The current state of the RoverNode.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this RoverNodeSummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this RoverNodeSummary.
        The current state of the RoverNode.


        :param lifecycle_state: The lifecycle_state of this RoverNodeSummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_state_details(self):
        """
        Gets the lifecycle_state_details of this RoverNodeSummary.
        A property that can contain details on the lifecycle.


        :return: The lifecycle_state_details of this RoverNodeSummary.
        :rtype: str
        """
        return self._lifecycle_state_details

    @lifecycle_state_details.setter
    def lifecycle_state_details(self, lifecycle_state_details):
        """
        Sets the lifecycle_state_details of this RoverNodeSummary.
        A property that can contain details on the lifecycle.


        :param lifecycle_state_details: The lifecycle_state_details of this RoverNodeSummary.
        :type: str
        """
        self._lifecycle_state_details = lifecycle_state_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this RoverNodeSummary.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this RoverNodeSummary.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this RoverNodeSummary.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this RoverNodeSummary.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this RoverNodeSummary.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this RoverNodeSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this RoverNodeSummary.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this RoverNodeSummary.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this RoverNodeSummary.
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this RoverNodeSummary.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this RoverNodeSummary.
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this RoverNodeSummary.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AbstractParserTestResultLogLine(object):
    """
    AbstractParserTestResultLogLine
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AbstractParserTestResultLogLine object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param original_log_line:
            The value to assign to the original_log_line property of this AbstractParserTestResultLogLine.
        :type original_log_line: str

        :param pre_processed_log_line:
            The value to assign to the pre_processed_log_line property of this AbstractParserTestResultLogLine.
        :type pre_processed_log_line: str

        """
        self.swagger_types = {
            'original_log_line': 'str',
            'pre_processed_log_line': 'str'
        }

        self.attribute_map = {
            'original_log_line': 'originalLogLine',
            'pre_processed_log_line': 'preProcessedLogLine'
        }

        self._original_log_line = None
        self._pre_processed_log_line = None

    @property
    def original_log_line(self):
        """
        Gets the original_log_line of this AbstractParserTestResultLogLine.
        The original log line.


        :return: The original_log_line of this AbstractParserTestResultLogLine.
        :rtype: str
        """
        return self._original_log_line

    @original_log_line.setter
    def original_log_line(self, original_log_line):
        """
        Sets the original_log_line of this AbstractParserTestResultLogLine.
        The original log line.


        :param original_log_line: The original_log_line of this AbstractParserTestResultLogLine.
        :type: str
        """
        self._original_log_line = original_log_line

    @property
    def pre_processed_log_line(self):
        """
        Gets the pre_processed_log_line of this AbstractParserTestResultLogLine.
        The pre-processed log line.


        :return: The pre_processed_log_line of this AbstractParserTestResultLogLine.
        :rtype: str
        """
        return self._pre_processed_log_line

    @pre_processed_log_line.setter
    def pre_processed_log_line(self, pre_processed_log_line):
        """
        Sets the pre_processed_log_line of this AbstractParserTestResultLogLine.
        The pre-processed log line.


        :param pre_processed_log_line: The pre_processed_log_line of this AbstractParserTestResultLogLine.
        :type: str
        """
        self._pre_processed_log_line = pre_processed_log_line

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .dhcp_option import DhcpOption
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DhcpDnsOption(DhcpOption):
    """
    DHCP option for specifying how DNS (hostname resolution) is handled in the subnets in the VCN.
    For more information, see
    `DNS in Your Virtual Cloud Network`__.

    __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm
    """

    #: A constant which can be used with the server_type property of a DhcpDnsOption.
    #: This constant has a value of "VcnLocal"
    SERVER_TYPE_VCN_LOCAL = "VcnLocal"

    #: A constant which can be used with the server_type property of a DhcpDnsOption.
    #: This constant has a value of "VcnLocalPlusInternet"
    SERVER_TYPE_VCN_LOCAL_PLUS_INTERNET = "VcnLocalPlusInternet"

    #: A constant which can be used with the server_type property of a DhcpDnsOption.
    #: This constant has a value of "CustomDnsServer"
    SERVER_TYPE_CUSTOM_DNS_SERVER = "CustomDnsServer"

    def __init__(self, **kwargs):
        """
        Initializes a new DhcpDnsOption object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.DhcpDnsOption.type` attribute
        of this class is ``DomainNameServer`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this DhcpDnsOption.
        :type type: str

        :param custom_dns_servers:
            The value to assign to the custom_dns_servers property of this DhcpDnsOption.
        :type custom_dns_servers: list[str]

        :param server_type:
            The value to assign to the server_type property of this DhcpDnsOption.
            Allowed values for this property are: "VcnLocal", "VcnLocalPlusInternet", "CustomDnsServer", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type server_type: str

        """
        self.swagger_types = {
            'type': 'str',
            'custom_dns_servers': 'list[str]',
            'server_type': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'custom_dns_servers': 'customDnsServers',
            'server_type': 'serverType'
        }

        self._type = None
        self._custom_dns_servers = None
        self._server_type = None
        self._type = 'DomainNameServer'

    @property
    def custom_dns_servers(self):
        """
        Gets the custom_dns_servers of this DhcpDnsOption.
        If you set `serverType` to `CustomDnsServer`, specify the
        IP address of at least one DNS server of your choice (three maximum).


        :return: The custom_dns_servers of this DhcpDnsOption.
        :rtype: list[str]
        """
        return self._custom_dns_servers

    @custom_dns_servers.setter
    def custom_dns_servers(self, custom_dns_servers):
        """
        Sets the custom_dns_servers of this DhcpDnsOption.
        If you set `serverType` to `CustomDnsServer`, specify the
        IP address of at least one DNS server of your choice (three maximum).


        :param custom_dns_servers: The custom_dns_servers of this DhcpDnsOption.
        :type: list[str]
        """
        self._custom_dns_servers = custom_dns_servers

    @property
    def server_type(self):
        """
        **[Required]** Gets the server_type of this DhcpDnsOption.
        * **VcnLocal:** Reserved for future use.

        * **VcnLocalPlusInternet:** Also referred to as \"Internet and VCN Resolver\".
        Instances can resolve internet hostnames (no internet gateway is required),
        and can resolve hostnames of instances in the VCN. This is the default
        value in the default set of DHCP options in the VCN. For the Internet and
        VCN Resolver to work across the VCN, there must also be a DNS label set for
        the VCN, a DNS label set for each subnet, and a hostname for each instance.
        The Internet and VCN Resolver also enables reverse DNS lookup, which lets
        you determine the hostname corresponding to the private IP address. For more
        information, see
        `DNS in Your Virtual Cloud Network`__.

        * **CustomDnsServer:** Instances use a DNS server of your choice (three
        maximum).

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm

        Allowed values for this property are: "VcnLocal", "VcnLocalPlusInternet", "CustomDnsServer", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The server_type of this DhcpDnsOption.
        :rtype: str
        """
        return self._server_type

    @server_type.setter
    def server_type(self, server_type):
        """
        Sets the server_type of this DhcpDnsOption.
        * **VcnLocal:** Reserved for future use.

        * **VcnLocalPlusInternet:** Also referred to as \"Internet and VCN Resolver\".
        Instances can resolve internet hostnames (no internet gateway is required),
        and can resolve hostnames of instances in the VCN. This is the default
        value in the default set of DHCP options in the VCN. For the Internet and
        VCN Resolver to work across the VCN, there must also be a DNS label set for
        the VCN, a DNS label set for each subnet, and a hostname for each instance.
        The Internet and VCN Resolver also enables reverse DNS lookup, which lets
        you determine the hostname corresponding to the private IP address. For more
        information, see
        `DNS in Your Virtual Cloud Network`__.

        * **CustomDnsServer:** Instances use a DNS server of your choice (three
        maximum).

        __ https://docs.cloud.oracle.com/iaas/Content/Network/Concepts/dns.htm


        :param server_type: The server_type of this DhcpDnsOption.
        :type: str
        """
        allowed_values = ["VcnLocal", "VcnLocalPlusInternet", "CustomDnsServer"]
        if not value_allowed_none_or_none_sentinel(server_type, allowed_values):
            server_type = 'UNKNOWN_ENUM_VALUE'
        self._server_type = server_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
